@@ -14,16 +14,12 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(get_performance_probability);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 NAME
 
 Performance::Probability - The performance probability is a likelihood measure of a client reaching his/her current profit and loss.
 
-=head1 VERSION
-
-0.04
-
 =head1 SYNOPSYS
 
   use Performance::Probability qw(get_performance_probability);
@@ -183,7 +179,7 @@ sub _covariance {
 
 =head2 get_performance_probability
 
-Calculate performance probability ( modified sharpe ratio ) 
+Calculate performance probability ( modified sharpe ratio )
 
 =cut
 
